/* ==========================================================================
        hello6.c
   --------------------------------------------------------------------------
        Copyright (C) 1989.  Daniel J. Reynolds.  All Rights Reserved.
        High Aspect Development Corporation
        9821 South Pulaski Road
        Evergreen Park, IL  60642   312-424-5997
   ========================================================================== */

#include <curses.h>
#include <string.h>

int attr_table[] = {        /* Readable attribute combinations */
    0x0100,
    0x0200,
    0x0300,
    0x0400,
    0x0500,
    0x0600,
    0x0700,
    0x1200,
    0x1300,
    0x1400,
    0x1500,
    0x1600,
    0x2300,
    0x2400,
    0x2500,
    0x2600,
    0x3400,
    0x3500,
    0x3600,
    0x4600,
    0x4700,
    0x5600,
    0x5700,
    0x6700,
};

#define N_WINDS 100             /* Number of windows to create */

struct {                        /* Array of Windows whose dimensions */
    WINDOW * outer;             /* We'll create randomly */
    WINDOW * inner;
    int s_row,s_col,n_rows,n_cols;
} wa[N_WINDS];

void main(void);
void many_wind(void);
void del_wind(void);
void build_wa(void);

/* -------------------------------------------------------------------------- */
void main () {

    initscr();
    raw();
    noecho();
    attr_trans = FALSE;
    break_on(&break_flag);
    many_wind();
    del_wind();
    break_off();
    endwin();
}
/* -------------------------------------------------------------------------- */
void many_wind() {

int i,j,type,count,m1len;
static char * message1 = " Hello World ! " ;  /* Message we'll display */

    m1len = strlen(message1);
    build_wa();                         /* Create the Window dimensions */
                                        /* randomly */
    for (i=0;i<N_WINDS;++i) {           /* Create & Display First */
        wa[i].outer = newwin(wa[i].n_rows,wa[i].n_cols,wa[i].s_row,wa[i].s_col);
        type = (i%(N_BOXES-1))+1;       /* Borders based on window numbers */
        if (v_getmod() == 3)
            A_NORMAL = attr_table[i%24];    /* Attribute based on index also */
        box(wa[i].outer,box_typ[type].v,box_typ[type].h);
        mvwprintw(wa[i].outer,0,1,"[%2.2d]",i); /* Window number */
        wrefresh(wa[i].outer);
    }
    for (i=0;i<N_WINDS;++i) {           /* Next Add the Message */
        wa[i].inner = newwin(wa[i].n_rows - 2,wa[i].n_cols -2 ,wa[i].s_row + 1,
                                                               wa[i].s_col + 1);
        count = (wa[i].n_rows - 2) * (wa[i].n_cols - 2);    /* number of chars
                                                               the window will
                                                               hold */
        if (v_getmod() == 3)
            A_NORMAL = attr_table[i%24];
        for (j=0;j<count;++j)       /* Add the characters */
            waddch(wa[i].inner,message1[j % m1len]);
        wnoutrefresh(wa[i].outer);
        wrefresh(wa[i].inner);
    }
    return;
}
/* -------------------------------------------------------------------------- */
void del_wind() {

int i;

    for (i=N_WINDS-1;i>=0;--i) {    /* Just get rid of 'em */
        delwin(wa[i].inner);
        delwin(wa[i].outer);
        doupdate();
    }
    return;
}
/* -------------------------------------------------------------------------- */
void build_wa() {

int rn,i;

    srand(1);       /* Random number seed */
    i = 0;          /* Get the number of rows */
    while(TRUE) {
        if (((rn = rand()%100) < 8) && rn > 3) {
            wa[i].n_rows = rn;
            if (++i == N_WINDS)
                break;
        }
    }
    i = 0;          /* Get the number of columns */
    while(TRUE) {
        if (((rn = rand()%100) < 20) && rn > 6) {
            wa[i].n_cols = rn;
            if (++i == N_WINDS)
                break;
        }
    }
    i = 0;          /* Get the start row */
    while(TRUE) {
        if ((rn = rand()%100) + wa[i].n_rows < LINES - 1) {
            wa[i].s_row = rn;
            if (++i == N_WINDS)
                break;
        }
    }
    i = 0;          /* Get the start column */
    while(TRUE) {
        if ((rn = rand()%100) + wa[i].n_cols < COLS - 1) {
            wa[i].s_col = rn;
            if (++i == N_WINDS)
                break;
        }
    }
    /* In the process make sure that none of the numbers exceeds the
       boundry limits */
}

