#include <curses.h>
#include "hanoi.h"

int	verbose, automatic;

main(c, v)
int c;
char **v;

{
	int nrings;

	if (c < 2 || c > 3) {
		fprintf(stderr,"usage: %s [-v|-a] <1-%d>\n", v[0], MAX_RINGS);
		exit(1);
	}
	if (strcmp(v[1], "-v") == 0)
		verbose++;
	else if (strcmp(v[1], "-a") == 0)
		automatic++;
	nrings = atoi(v[c-1]);
	if (!nrings || nrings > MAX_RINGS) {
		fprintf(stderr, "usage: %s [-v] <1-%d>\n", v[0], MAX_RINGS);
		exit(1);
	}

	init_curses();
	init_pegs(nrings);
	draw_slab();
	draw_pegs();
	draw_rings(nrings);
	if (automatic) {
		hanoi(nrings, 0, 1);
		goodbye();
	}
	Interactive();
}

Interactive()

{
	int from, to, fromdisk, todisk;

    cbreak();
	noecho();
	for (;;) {
		from = GetNumber("Move disk from peg: ");
		if (peg_height(from-1) == 0) {
			Message("No disk on that peg...");
            d_sleep(2);
			continue;
		}
		fromdisk = pop(from-1);
		push(from-1, fromdisk);
		Light(from-1);
		to = GetNumber("To peg: ");
		if (peg_height(to-1) != 0) {
			todisk = pop(to-1);
			push(to-1, todisk);
			if (fromdisk > todisk) {
				Douse(from-1);
		    Message("Cannot move larger disk onto smaller one.");
                d_sleep(2);
				continue;
			}
		}
		Message("");
		movering(from-1, to-1);
		if (!peg_height(0) && (!peg_height(1) || !peg_height(2))) {
		  switch (peg_height(to-1)) {
		    case 1:
		      Message("Phhhhft!"); break;
		    case 2:
		      Message("Ha!"); break;
		    case 3:
		      Message("Well, it's about time!"); break;
		    case 4:
		      Message("Not bad... for a human."); break;
		    case 5:
		      Message("Finally!"); break;
		    case 6:
		      Message("Good, now be gone!"); break;
		    default:
		      Message("It was pure luck!"); break;
		  }
		  getch();
		  goodbye(0);
	      }
	}
}

int
GetNumber(prompt)
char *prompt;

{
	char c;

	move(LINES-1, 0);
	clrtoeol();
	addstr(prompt);
	refresh();
	for (;;) {
		c = getch();
		if (c == 'q' || c == 'Q')
			goodbye();
		if (c > '0' && c < '4')
			break;
	}
	return (int) (c - '0');
}

Message(string)
char *string;

{
	move(LINES-1, 0);
	clrtoeol();
	move(LINES-1, 0);
	standout();
	addstr(string);
    standend();
	refresh();
	return;
}


